@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from kolla_ansible.version import version_info as kolla_version
 import os
 import sys
 
@@ -44,7 +45,6 @@ copyright = u'2013, OpenStack Foundation'
 # built documents.
 #
 # The short X.Y version.
-from kolla_ansible.version import version_info as kolla_version
 # The full version, including alpha/beta/rc tags.
 release = kolla_version.version_string_with_vcs()
 # The short X.Y version.
@@ -89,5 +89,19 @@ repository_name = 'openstack/kolla-ansible'
 bug_project = 'kolla-ansible'
 bug_tag = ''
 openstack_projects = [
+    'bifrost',
+    'cinder',
+    'designate',
+    'glance',
+    'ironic',
+    'keystone',
+    'kolla',
     'kolla-ansible',
+    'manila',
+    'networking-sfc',
+    'neutron-vpnaas',
+    'neutron',
+    'nova',
+    'oslotest',
+    'swift',
 ]
