@@ -87,8 +87,6 @@ copy_logs() {
     done
 
     chmod -R 777 ${LOG_DIR}
-    find ${LOG_DIR}/{system_logs,kolla,docker_logs} -iname '*.txt' -execdir gzip -f -9 {} \+
-    find ${LOG_DIR}/{system_logs,kolla,docker_logs} -iname '*.json' -execdir gzip -f -9 {} \+
 }
 
 copy_logs
